summaryrefslogtreecommitdiffstats
path: root/bibletime/frontend/searchdialog/csearchdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'bibletime/frontend/searchdialog/csearchdialog.cpp')
-rw-r--r--bibletime/frontend/searchdialog/csearchdialog.cpp60
1 files changed, 30 insertions, 30 deletions
diff --git a/bibletime/frontend/searchdialog/csearchdialog.cpp b/bibletime/frontend/searchdialog/csearchdialog.cpp
index beef7c4..af1538a 100644
--- a/bibletime/frontend/searchdialog/csearchdialog.cpp
+++ b/bibletime/frontend/searchdialog/csearchdialog.cpp
@@ -24,20 +24,20 @@
#include "util/ctoolclass.h"
//Qt includes
-#include <qhbox.h>
-#include <qvbox.h>
-#include <qptrlist.h>
-#include <qpainter.h>
-#include <qlayout.h>
-#include <qmap.h>
-#include <qlineedit.h>
-#include <qtextedit.h>
-#include <qlabel.h>
-#include <qsizepolicy.h>
-#include <qpushbutton.h>
-#include <qheader.h>
-#include <qregexp.h>
-#include <qmessagebox.h>
+#include <tqhbox.h>
+#include <tqvbox.h>
+#include <tqptrlist.h>
+#include <tqpainter.h>
+#include <tqlayout.h>
+#include <tqmap.h>
+#include <tqlineedit.h>
+#include <tqtextedit.h>
+#include <tqlabel.h>
+#include <tqsizepolicy.h>
+#include <tqpushbutton.h>
+#include <tqheader.h>
+#include <tqregexp.h>
+#include <tqmessagebox.h>
//KDE includes
#include <kapplication.h>
@@ -49,7 +49,7 @@ namespace Search {
static CSearchDialog* m_staticDialog = 0;
-void CSearchDialog::openDialog(const ListCSwordModuleInfo modules, const QString& searchText, QWidget* parentDialog) {
+void CSearchDialog::openDialog(const ListCSwordModuleInfo modules, const TQString& searchText, TQWidget* parentDialog) {
if (!m_staticDialog) {
m_staticDialog = new CSearchDialog(parentDialog);
};
@@ -81,13 +81,13 @@ CSearchDialog* const CSearchDialog::getSearchDialog() {
return m_staticDialog;
};
-CSearchDialog::CSearchDialog(QWidget *parent)
+CSearchDialog::CSearchDialog(TQWidget *parent)
: KDialogBase(Plain, i18n("Search dialog"), Close | User1, User1, parent, "CSearchDialog", false, true, i18n("Search")) {
setWFlags( getWFlags() | Qt::WStyle_MinMax );
setIcon(CResMgr::searchdialog::icon);
- m_searcher.connectFinished( this, SLOT(searchFinished()));
+ m_searcher.connectFinished( this, TQT_SLOT(searchFinished()));
initView();
initConnections();
@@ -100,7 +100,7 @@ CSearchDialog::~CSearchDialog(){
/** Starts the search with the set modules and the set search text. */
void CSearchDialog::startSearch() {
- QString searchText(m_searchOptionsPage->searchText());
+ TQString searchText(m_searchOptionsPage->searchText());
if (searchText.isEmpty()) {
return;
@@ -108,15 +108,15 @@ void CSearchDialog::startSearch() {
// check that we have the indices we need for searching
if (!m_searcher.modulesHaveIndices( modules() ) ) {
- int result = QMessageBox::question(this, i18n("Missing indices"),
+ int result = TQMessageBox::question(this, i18n("Missing indices"),
i18n("One or more modules need indexing before they can be searched.\n"
"This could take a long time. Proceed with indexing?"),
- QMessageBox::Yes | QMessageBox::Default,
- QMessageBox::No | QMessageBox::Escape);
+ TQMessageBox::Yes | TQMessageBox::Default,
+ TQMessageBox::No | TQMessageBox::Escape);
// In SuSE 10.0 the result is the logical or of the button type, just like it is
- // inputed into the QMessageBox.
- if ( (result == (QMessageBox::Yes | QMessageBox::Default)) ||
- (result == QMessageBox::Yes) || (result == QMessageBox::Default) ) {
+ // inputed into the TQMessageBox.
+ if ( (result == (TQMessageBox::Yes | TQMessageBox::Default)) ||
+ (result == TQMessageBox::Yes) || (result == TQMessageBox::Default) ) {
CModuleIndexDialog* dlg = CModuleIndexDialog::getInstance();
dlg->indexUnindexedModules( modules() );
}
@@ -155,7 +155,7 @@ void CSearchDialog::startSearch() {
}
/** Starts the search with the given module list and given search text. */
-void CSearchDialog::startSearch( const ListCSwordModuleInfo modules, const QString& searchText) {
+void CSearchDialog::startSearch( const ListCSwordModuleInfo modules, const TQString& searchText) {
m_searchResultPage->reset();
m_searchOptionsPage->reset();
setModules(modules);
@@ -176,7 +176,7 @@ void CSearchDialog::setModules( const ListCSwordModuleInfo modules ) {
}
/** Returns the search text which is set currently. */
-const QString CSearchDialog::searchText() {
+const TQString CSearchDialog::searchText() {
return m_searchOptionsPage->searchText();
}
@@ -195,7 +195,7 @@ sword::ListKey CSearchDialog::searchScope() {
// }
/** Returns the search text which is used for the search. */
-void CSearchDialog::setSearchText( const QString searchText ) {
+void CSearchDialog::setSearchText( const TQString searchText ) {
m_searchOptionsPage->setSearchText(searchText);
}
@@ -203,7 +203,7 @@ void CSearchDialog::setSearchText( const QString searchText ) {
void CSearchDialog::initView() {
setButtonTip(User1, CResMgr::searchdialog::searchButton::tooltip);
- QVBoxLayout *box = new QVBoxLayout( plainPage(), 0, spacingHint() );
+ TQVBoxLayout *box = new TQVBoxLayout( plainPage(), 0, spacingHint() );
m_searchOptionsPage = new Options::CSearchOptionsPage(plainPage());
box->addWidget( m_searchOptionsPage );
@@ -244,8 +244,8 @@ void CSearchDialog::showModulesSelector() {
/** Initializes the signal slot connections */
void CSearchDialog::initConnections() {
- connect(this, SIGNAL(user1Clicked()), SLOT(startSearch()));
- connect(this, SIGNAL(closeClicked()), SLOT(slotDelayedDestruct()));
+ connect(this, TQT_SIGNAL(user1Clicked()), TQT_SLOT(startSearch()));
+ connect(this, TQT_SIGNAL(closeClicked()), TQT_SLOT(slotDelayedDestruct()));
}
/** Resets the parts to the default. */